/********************************************************************************
** Form generated from reading UI file 'lc_layertreeoptionsdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LC_LAYERTREEOPTIONSDIALOG_H
#define UI_LC_LAYERTREEOPTIONSDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include "qg_widgetpen.h"

QT_BEGIN_NAMESPACE

class Ui_LC_LayerTreeOptionsDialog
{
public:
    QFormLayout *formLayout_3;
    QTabWidget *tabWidget;
    QWidget *tabNaming;
    QGridLayout *gridLayout_3;
    QSpacerItem *horizontalSpacer_3;
    QLineEdit *leLayerLevelSeparator;
    QLabel *label;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QFormLayout *formLayout_2;
    QLabel *label_2;
    QLineEdit *leDimSuffix;
    QLabel *label_3;
    QLineEdit *leInfoSuffix;
    QLabel *label_4;
    QLineEdit *leAltPosSuffix;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *label_5;
    QLineEdit *leDuplicatedPrefix;
    QLabel *label_61;
    QLineEdit *leDuplicatedSuffix;
    QWidget *tabDisplay;
    QGridLayout *gridLayout_4;
    QCheckBox *cbShowToolTip;
    QCheckBox *cbShowTypeIcons;
    QCheckBox *cbShowIdented;
    QSpinBox *sbIndentSize;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *cbDragDrop;
    QCheckBox *cbRenameWithPrimary;
    QWidget *tabColors;
    QGridLayout *gridLayout_2;
    QComboBox *cbSelectedItemBgColor;
    QComboBox *cbGridColor;
    QComboBox *cbVirtualLayerBackgroundColor;
    QPushButton *pb_selectedItemColor;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_6;
    QComboBox *cbActiveLayerBgColor;
    QComboBox *cbHighlightedColor;
    QPushButton *pb_highlightedColor;
    QLabel *lRelativeZeroColor;
    QPushButton *pb_gridColor;
    QLabel *lBackground;
    QLabel *label_7;
    QPushButton *pbActiveLayerBgColor;
    QPushButton *pbSelectedItemsBgColor;
    QLabel *label_8;
    QSpacerItem *horizontalSpacer_2;
    QWidget *tabPens;
    QGridLayout *gridLayout;
    QG_WidgetPen *wPenDimensional;
    QG_WidgetPen *wPenInfo;
    QG_WidgetPen *wPenNormal;
    QG_WidgetPen *wPenAltPos;
    QSpacerItem *verticalSpacer_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *LC_LayerTreeOptionsDialog)
    {
        if (LC_LayerTreeOptionsDialog->objectName().isEmpty())
            LC_LayerTreeOptionsDialog->setObjectName(QString::fromUtf8("LC_LayerTreeOptionsDialog"));
        LC_LayerTreeOptionsDialog->resize(491, 268);
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(LC_LayerTreeOptionsDialog->sizePolicy().hasHeightForWidth());
        LC_LayerTreeOptionsDialog->setSizePolicy(sizePolicy);
        formLayout_3 = new QFormLayout(LC_LayerTreeOptionsDialog);
        formLayout_3->setObjectName(QString::fromUtf8("formLayout_3"));
        tabWidget = new QTabWidget(LC_LayerTreeOptionsDialog);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabWidget->setTabPosition(QTabWidget::North);
        tabNaming = new QWidget();
        tabNaming->setObjectName(QString::fromUtf8("tabNaming"));
        gridLayout_3 = new QGridLayout(tabNaming);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 0, 3, 1, 1);

        leLayerLevelSeparator = new QLineEdit(tabNaming);
        leLayerLevelSeparator->setObjectName(QString::fromUtf8("leLayerLevelSeparator"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(leLayerLevelSeparator->sizePolicy().hasHeightForWidth());
        leLayerLevelSeparator->setSizePolicy(sizePolicy1);
        leLayerLevelSeparator->setMaxLength(10);

        gridLayout_3->addWidget(leLayerLevelSeparator, 0, 1, 1, 2);

        label = new QLabel(tabNaming);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 2, 0, 1, 1);

        groupBox = new QGroupBox(tabNaming);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        formLayout_2 = new QFormLayout(groupBox);
        formLayout_2->setObjectName(QString::fromUtf8("formLayout_2"));
        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, label_2);

        leDimSuffix = new QLineEdit(groupBox);
        leDimSuffix->setObjectName(QString::fromUtf8("leDimSuffix"));
        sizePolicy1.setHeightForWidth(leDimSuffix->sizePolicy().hasHeightForWidth());
        leDimSuffix->setSizePolicy(sizePolicy1);
        leDimSuffix->setMaxLength(10);

        formLayout_2->setWidget(0, QFormLayout::FieldRole, leDimSuffix);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, label_3);

        leInfoSuffix = new QLineEdit(groupBox);
        leInfoSuffix->setObjectName(QString::fromUtf8("leInfoSuffix"));
        sizePolicy1.setHeightForWidth(leInfoSuffix->sizePolicy().hasHeightForWidth());
        leInfoSuffix->setSizePolicy(sizePolicy1);
        leInfoSuffix->setMaxLength(10);

        formLayout_2->setWidget(1, QFormLayout::FieldRole, leInfoSuffix);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        formLayout_2->setWidget(2, QFormLayout::LabelRole, label_4);

        leAltPosSuffix = new QLineEdit(groupBox);
        leAltPosSuffix->setObjectName(QString::fromUtf8("leAltPosSuffix"));
        sizePolicy1.setHeightForWidth(leAltPosSuffix->sizePolicy().hasHeightForWidth());
        leAltPosSuffix->setSizePolicy(sizePolicy1);
        leAltPosSuffix->setMaxLength(10);

        formLayout_2->setWidget(2, QFormLayout::FieldRole, leAltPosSuffix);


        gridLayout_3->addWidget(groupBox, 1, 0, 1, 3);

        groupBox_2 = new QGroupBox(tabNaming);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label_5);

        leDuplicatedPrefix = new QLineEdit(groupBox_2);
        leDuplicatedPrefix->setObjectName(QString::fromUtf8("leDuplicatedPrefix"));
        sizePolicy1.setHeightForWidth(leDuplicatedPrefix->sizePolicy().hasHeightForWidth());
        leDuplicatedPrefix->setSizePolicy(sizePolicy1);
        leDuplicatedPrefix->setMaxLength(10);

        formLayout->setWidget(0, QFormLayout::FieldRole, leDuplicatedPrefix);

        label_61 = new QLabel(groupBox_2);
        label_61->setObjectName(QString::fromUtf8("label_61"));

        formLayout->setWidget(1, QFormLayout::LabelRole, label_61);

        leDuplicatedSuffix = new QLineEdit(groupBox_2);
        leDuplicatedSuffix->setObjectName(QString::fromUtf8("leDuplicatedSuffix"));
        sizePolicy1.setHeightForWidth(leDuplicatedSuffix->sizePolicy().hasHeightForWidth());
        leDuplicatedSuffix->setSizePolicy(sizePolicy1);
        leDuplicatedSuffix->setMaxLength(10);

        formLayout->setWidget(1, QFormLayout::FieldRole, leDuplicatedSuffix);


        gridLayout_3->addWidget(groupBox_2, 1, 3, 1, 1);

        tabWidget->addTab(tabNaming, QString());
        tabDisplay = new QWidget();
        tabDisplay->setObjectName(QString::fromUtf8("tabDisplay"));
        gridLayout_4 = new QGridLayout(tabDisplay);
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        cbShowToolTip = new QCheckBox(tabDisplay);
        cbShowToolTip->setObjectName(QString::fromUtf8("cbShowToolTip"));

        gridLayout_4->addWidget(cbShowToolTip, 0, 0, 1, 1);

        cbShowTypeIcons = new QCheckBox(tabDisplay);
        cbShowTypeIcons->setObjectName(QString::fromUtf8("cbShowTypeIcons"));

        gridLayout_4->addWidget(cbShowTypeIcons, 1, 0, 1, 1);

        cbShowIdented = new QCheckBox(tabDisplay);
        cbShowIdented->setObjectName(QString::fromUtf8("cbShowIdented"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbShowIdented->sizePolicy().hasHeightForWidth());
        cbShowIdented->setSizePolicy(sizePolicy2);

        gridLayout_4->addWidget(cbShowIdented, 2, 0, 1, 1);

        sbIndentSize = new QSpinBox(tabDisplay);
        sbIndentSize->setObjectName(QString::fromUtf8("sbIndentSize"));
        sbIndentSize->setMinimum(1);
        sbIndentSize->setMaximum(12);

        gridLayout_4->addWidget(sbIndentSize, 2, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(120, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_4, 2, 2, 1, 1);

        cbDragDrop = new QCheckBox(tabDisplay);
        cbDragDrop->setObjectName(QString::fromUtf8("cbDragDrop"));

        gridLayout_4->addWidget(cbDragDrop, 3, 0, 1, 1);

        cbRenameWithPrimary = new QCheckBox(tabDisplay);
        cbRenameWithPrimary->setObjectName(QString::fromUtf8("cbRenameWithPrimary"));

        gridLayout_4->addWidget(cbRenameWithPrimary, 4, 0, 1, 2);

        tabWidget->addTab(tabDisplay, QString());
        tabColors = new QWidget();
        tabColors->setObjectName(QString::fromUtf8("tabColors"));
        gridLayout_2 = new QGridLayout(tabColors);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        cbSelectedItemBgColor = new QComboBox(tabColors);
        cbSelectedItemBgColor->setObjectName(QString::fromUtf8("cbSelectedItemBgColor"));
        cbSelectedItemBgColor->setEditable(true);

        gridLayout_2->addWidget(cbSelectedItemBgColor, 2, 1, 1, 1);

        cbGridColor = new QComboBox(tabColors);
        cbGridColor->addItem(QString::fromUtf8("#000000"));
        cbGridColor->addItem(QString::fromUtf8("#FFFFFF"));
        cbGridColor->addItem(QString::fromUtf8("#F0F8FF"));
        cbGridColor->setObjectName(QString::fromUtf8("cbGridColor"));
        sizePolicy2.setHeightForWidth(cbGridColor->sizePolicy().hasHeightForWidth());
        cbGridColor->setSizePolicy(sizePolicy2);
#if QT_CONFIG(accessibility)
        cbGridColor->setAccessibleDescription(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)
        cbGridColor->setEditable(true);

        gridLayout_2->addWidget(cbGridColor, 4, 1, 1, 1);

        cbVirtualLayerBackgroundColor = new QComboBox(tabColors);
        cbVirtualLayerBackgroundColor->addItem(QString::fromUtf8("#1E90FF"));
        cbVirtualLayerBackgroundColor->addItem(QString::fromUtf8("#FFC200"));
        cbVirtualLayerBackgroundColor->setObjectName(QString::fromUtf8("cbVirtualLayerBackgroundColor"));
        sizePolicy2.setHeightForWidth(cbVirtualLayerBackgroundColor->sizePolicy().hasHeightForWidth());
        cbVirtualLayerBackgroundColor->setSizePolicy(sizePolicy2);
#if QT_CONFIG(accessibility)
        cbVirtualLayerBackgroundColor->setAccessibleDescription(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)
        cbVirtualLayerBackgroundColor->setEditable(true);

        gridLayout_2->addWidget(cbVirtualLayerBackgroundColor, 1, 1, 1, 1);

        pb_selectedItemColor = new QPushButton(tabColors);
        pb_selectedItemColor->setObjectName(QString::fromUtf8("pb_selectedItemColor"));
        QSizePolicy sizePolicy3(QSizePolicy::Maximum, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(pb_selectedItemColor->sizePolicy().hasHeightForWidth());
        pb_selectedItemColor->setSizePolicy(sizePolicy3);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/ui/colorxx.png"), QSize(), QIcon::Normal, QIcon::Off);
        pb_selectedItemColor->setIcon(icon);

        gridLayout_2->addWidget(pb_selectedItemColor, 1, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 5, 0, 1, 1);

        label_6 = new QLabel(tabColors);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout_2->addWidget(label_6, 0, 0, 1, 1);

        cbActiveLayerBgColor = new QComboBox(tabColors);
        cbActiveLayerBgColor->setObjectName(QString::fromUtf8("cbActiveLayerBgColor"));
        cbActiveLayerBgColor->setEditable(true);

        gridLayout_2->addWidget(cbActiveLayerBgColor, 3, 1, 1, 1);

        cbHighlightedColor = new QComboBox(tabColors);
        cbHighlightedColor->addItem(QString::fromUtf8("#FFC200"));
        cbHighlightedColor->addItem(QString());
        cbHighlightedColor->setObjectName(QString::fromUtf8("cbHighlightedColor"));
        sizePolicy2.setHeightForWidth(cbHighlightedColor->sizePolicy().hasHeightForWidth());
        cbHighlightedColor->setSizePolicy(sizePolicy2);
#if QT_CONFIG(accessibility)
        cbHighlightedColor->setAccessibleDescription(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)
        cbHighlightedColor->setEditable(true);

        gridLayout_2->addWidget(cbHighlightedColor, 0, 1, 1, 1);

        pb_highlightedColor = new QPushButton(tabColors);
        pb_highlightedColor->setObjectName(QString::fromUtf8("pb_highlightedColor"));
        sizePolicy3.setHeightForWidth(pb_highlightedColor->sizePolicy().hasHeightForWidth());
        pb_highlightedColor->setSizePolicy(sizePolicy3);
        pb_highlightedColor->setIcon(icon);

        gridLayout_2->addWidget(pb_highlightedColor, 0, 2, 1, 1);

        lRelativeZeroColor = new QLabel(tabColors);
        lRelativeZeroColor->setObjectName(QString::fromUtf8("lRelativeZeroColor"));

        gridLayout_2->addWidget(lRelativeZeroColor, 1, 0, 1, 1);

        pb_gridColor = new QPushButton(tabColors);
        pb_gridColor->setObjectName(QString::fromUtf8("pb_gridColor"));
        sizePolicy3.setHeightForWidth(pb_gridColor->sizePolicy().hasHeightForWidth());
        pb_gridColor->setSizePolicy(sizePolicy3);
        pb_gridColor->setIcon(icon);

        gridLayout_2->addWidget(pb_gridColor, 4, 2, 1, 1);

        lBackground = new QLabel(tabColors);
        lBackground->setObjectName(QString::fromUtf8("lBackground"));
        lBackground->setWordWrap(false);

        gridLayout_2->addWidget(lBackground, 4, 0, 1, 1);

        label_7 = new QLabel(tabColors);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout_2->addWidget(label_7, 2, 0, 1, 1);

        pbActiveLayerBgColor = new QPushButton(tabColors);
        pbActiveLayerBgColor->setObjectName(QString::fromUtf8("pbActiveLayerBgColor"));
        pbActiveLayerBgColor->setIcon(icon);

        gridLayout_2->addWidget(pbActiveLayerBgColor, 3, 2, 1, 1);

        pbSelectedItemsBgColor = new QPushButton(tabColors);
        pbSelectedItemsBgColor->setObjectName(QString::fromUtf8("pbSelectedItemsBgColor"));
        pbSelectedItemsBgColor->setIcon(icon);

        gridLayout_2->addWidget(pbSelectedItemsBgColor, 2, 2, 1, 1);

        label_8 = new QLabel(tabColors);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout_2->addWidget(label_8, 3, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 1, 3, 1, 1);

        tabWidget->addTab(tabColors, QString());
        tabPens = new QWidget();
        tabPens->setObjectName(QString::fromUtf8("tabPens"));
        gridLayout = new QGridLayout(tabPens);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        wPenDimensional = new QG_WidgetPen(tabPens);
        wPenDimensional->setObjectName(QString::fromUtf8("wPenDimensional"));

        gridLayout->addWidget(wPenDimensional, 0, 1, 1, 1);

        wPenInfo = new QG_WidgetPen(tabPens);
        wPenInfo->setObjectName(QString::fromUtf8("wPenInfo"));

        gridLayout->addWidget(wPenInfo, 1, 1, 1, 1);

        wPenNormal = new QG_WidgetPen(tabPens);
        wPenNormal->setObjectName(QString::fromUtf8("wPenNormal"));

        gridLayout->addWidget(wPenNormal, 0, 0, 1, 1);

        wPenAltPos = new QG_WidgetPen(tabPens);
        wPenAltPos->setObjectName(QString::fromUtf8("wPenAltPos"));

        gridLayout->addWidget(wPenAltPos, 1, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 3, 0, 1, 1);

        tabWidget->addTab(tabPens, QString());

        formLayout_3->setWidget(0, QFormLayout::SpanningRole, tabWidget);

        buttonBox = new QDialogButtonBox(LC_LayerTreeOptionsDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout_3->setWidget(1, QFormLayout::SpanningRole, buttonBox);


        retranslateUi(LC_LayerTreeOptionsDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), LC_LayerTreeOptionsDialog, SLOT(validate()));
        QObject::connect(buttonBox, SIGNAL(rejected()), LC_LayerTreeOptionsDialog, SLOT(reject()));
        QObject::connect(pb_highlightedColor, SIGNAL(clicked()), LC_LayerTreeOptionsDialog, SLOT(pb_highlightedColorClicked()));
        QObject::connect(pb_gridColor, SIGNAL(clicked()), LC_LayerTreeOptionsDialog, SLOT(pb_gridColorClicked()));
        QObject::connect(pbSelectedItemsBgColor, SIGNAL(clicked()), LC_LayerTreeOptionsDialog, SLOT(pbSelectedItemsBgColorClicked()));
        QObject::connect(pbActiveLayerBgColor, SIGNAL(clicked()), LC_LayerTreeOptionsDialog, SLOT(pbActiveLayerBgColorClicked()));
        QObject::connect(pb_selectedItemColor, SIGNAL(clicked()), LC_LayerTreeOptionsDialog, SLOT(pb_selectedItemColorClicked()));
        QObject::connect(cbShowIdented, SIGNAL(stateChanged(int)), LC_LayerTreeOptionsDialog, SLOT(showIndentedClicked()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(LC_LayerTreeOptionsDialog);
    } // setupUi

    void retranslateUi(QDialog *LC_LayerTreeOptionsDialog)
    {
        LC_LayerTreeOptionsDialog->setWindowTitle(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Layers Tree Options", nullptr));
        leLayerLevelSeparator->setText(QString());
        label->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Layer Level Name Separator", nullptr));
        groupBox->setTitle(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Secondary Layer Suffixes", nullptr));
        label_2->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Dimensional", nullptr));
        label_3->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Informational", nullptr));
        label_4->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Alternative Position ", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Duplicating Name", nullptr));
        label_5->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Prefix", nullptr));
        label_61->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Suffix", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabNaming), QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Naming Convention", nullptr));
        cbShowToolTip->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Show full name as ToolTip", nullptr));
        cbShowTypeIcons->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Show layer type icons", nullptr));
        cbShowIdented->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Show indented layer names. Ident size:", nullptr));
        sbIndentSize->setSuffix(QString());
        cbDragDrop->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Allow restructuring via Drag&Drop", nullptr));
        cbRenameWithPrimary->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Rename secondary layers on primary rename", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDisplay), QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Display and Operations", nullptr));
        cbSelectedItemBgColor->setCurrentText(QString());


        pb_selectedItemColor->setText(QString());
        label_6->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Matched item in highlight filter mode", nullptr));
        cbHighlightedColor->setItemText(1, QCoreApplication::translate("LC_LayerTreeOptionsDialog", "#1E90FF", nullptr));

        pb_highlightedColor->setText(QString());
        lRelativeZeroColor->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Virtual layer background color", nullptr));
        pb_gridColor->setText(QString());
        lBackground->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Threeview items separator grid", nullptr));
        label_7->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Selected items background color", nullptr));
        pbActiveLayerBgColor->setText(QString());
        pbSelectedItemsBgColor->setText(QString());
        label_8->setText(QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Active layer background color", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabColors), QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Colors", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabPens), QCoreApplication::translate("LC_LayerTreeOptionsDialog", "Default Pens", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LC_LayerTreeOptionsDialog: public Ui_LC_LayerTreeOptionsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LC_LAYERTREEOPTIONSDIALOG_H
